
#ifndef VTKPVADAPTORSCAM_EXPORT_H
#define VTKPVADAPTORSCAM_EXPORT_H

#ifdef VTKPVADAPTORSCAM_STATIC_DEFINE
#  define VTKPVADAPTORSCAM_EXPORT
#  define VTKPVADAPTORSCAM_NO_EXPORT
#else
#  ifndef VTKPVADAPTORSCAM_EXPORT
#    ifdef AdaptorsCam_EXPORTS
        /* We are building this library */
#      define VTKPVADAPTORSCAM_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVADAPTORSCAM_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVADAPTORSCAM_NO_EXPORT
#    define VTKPVADAPTORSCAM_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVADAPTORSCAM_DEPRECATED
#  define VTKPVADAPTORSCAM_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVADAPTORSCAM_DEPRECATED_EXPORT
#  define VTKPVADAPTORSCAM_DEPRECATED_EXPORT VTKPVADAPTORSCAM_EXPORT VTKPVADAPTORSCAM_DEPRECATED
#endif

#ifndef VTKPVADAPTORSCAM_DEPRECATED_NO_EXPORT
#  define VTKPVADAPTORSCAM_DEPRECATED_NO_EXPORT VTKPVADAPTORSCAM_NO_EXPORT VTKPVADAPTORSCAM_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVADAPTORSCAM_NO_DEPRECATED
#    define VTKPVADAPTORSCAM_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVAdaptorsCamModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVADAPTORSCAM_EXPORT_H */
